@@ -1222,6 +1222,7 @@ class yank(commands.Command):
 		parser.add_argument("--clipboard", "-c", dest="selection", action="store_const", const=cls.SELECTION_CLIPBOARD)
 		parser.add_argument("--no-git", "-n", action="store_true", help=_("do not replace git placeholders (works also with unstaged and uncommitted changes)"))
 		parser.add_argument("--follow", "-f", action="store_true", help=_("select a hash id which you want to copy the information for (like with the command `link`)"))
+		parser.add_argument("--verbose", action="store_true", help=_("show the command used to copy the information"))
 
 	@classmethod
 	def init_help(cls, parser):
@@ -1241,6 +1242,7 @@ class yank(commands.Command):
 
 
 	def execute(self, args):
+		self.verbose = args.verbose
 		if args.follow:
 			self.app.show_hints(lambda hint_type, hash_id: self.execute2(args, hint_type, hash_id, self.app.TYPE_OTHER))
 		else:
@@ -1336,6 +1338,8 @@ class yank(commands.Command):
 		cmd.append("--")
 		cmd.append(text)
 
+		if self.verbose:
+			self.app.show_info(shlex.join(cmd))
 		self.run(cmd, check=True)
 
 	def copy_xsel(self, text, selection):
@@ -1345,6 +1349,8 @@ class yank(commands.Command):
 			selection = "--clipboard"
 
 		cmd = ["xsel", "-i", selection]
+		if self.verbose:
+			self.app.show_info(shlex.join(cmd))
 		self.run(cmd, stdin=text, check=True)
 
 	def copy_xclip(self, text, selection):
@@ -1354,6 +1360,8 @@ class yank(commands.Command):
 			selection = "clipboard"
 
 		cmd = ["xclip", "-in", "-selection", selection]
+		if self.verbose:
+			self.app.show_info(shlex.join(cmd))
 		self.run(cmd, stdin=text, check=True)
 
 
