@@ -1316,7 +1316,13 @@ class Opener:
 			os.chmod(tmpfn, stat.S_IREAD)
 			self.open_file_in_editor(f.name, line_number, read_only=True)
 
-	def open_file_in_editor(self, fn, line_number, read_only=False):
+	def open_file_in_editor(self, fn, line_number, read_only=False, create_dirs=False):
+		if not os.path.exists(fn):
+			if create_dirs:
+				path = os.path.split(os.path.abspath(fn))[0]
+				os.makedirs(path, exist_ok=True)
+			else:
+				raise FileNotFoundError(fn)
 		if line_number == 0:
 			line_number = 1
 		runner = Runner()
