@@ -304,7 +304,7 @@ def format_value(value, allowed_values):
 	elif allowed_values == TYPE_COMMAND:
 		if isinstance(value[0], str):
 			value = [value]
-		return '; '.join(shlex.join(cmd) for cmd in value)
+		return '; '.join(shlex_join(cmd) for cmd in value)
 
 	return str(value)
 
@@ -332,3 +332,10 @@ def rsetattr(obj, name, value):
 		setattr(obj, name, value)
 	else:
 		raise AttributeError("%s does not have attribute %s" % (obj, name))
+
+
+def shlex_join(cmd):
+	# this function is intended to be equivalent to shlex.join
+	# I am not using shlex.join for backward compatibility with Python < 3.8
+	# https://docs.python.org/3/library/shlex.html#shlex.join
+	return " ".join(shlex.quote(w) for w in cmd)
